function [LS, DS, DZ, LZ] = find_cell(pt_fi, pt_la, geoid)
    % FIND_CELL funkcija kot vhodna parametra sprejeme elipsoidne koordinate točke in model geoida ter
    % vrne koordinate in geoidne višine vogalov gridne celice, v kateri leži podana točka.
    % 
    %   [LS, DS, DZ, LZ] = find_cell(pt_fi, pt_la, geoid)
    %
    %   VHODNI PARAMETRI:
    %     pt_fi ... elipsoidna širina točke [°]
    %     pt_la ... elipsoidna dolžina točke [°]
    %     geoid ... model geoida
    %
    %   IZHODNI PARAMETRI:
    %     LS ... struktura, ki vsebuje koordinate in geoidno višino levega spodnjega vogala celice
    %     DS ... struktura, ki vsebuje koordinate in geoidno višino desnega spodnjega vogala celice
    %     DZ ... struktura, ki vsebuje koordinate in geoidno višino desnega zgornjega vogala celice 
    %     LZ ... struktura, ki vsebuje koordinate in geoidno višino levega zgornjega vogala celice
    %     Struktura vogal ima sledeče atribute:
    %         fi ... elipsoidna širina vogala [°]
    %         la ... elipsoidna dolžina vogala [°]
    %          N ... geoidna višina vogala [m]
    %
    %   AVTOR: Klemen Ritlop
    %   2025-03-24

    % poišči indekse vogalov celice, v kateri leži točka
    fi_min_idx = find(geoid.fi < pt_fi, 1,'first');
    fi_max_idx = find(geoid.fi > pt_fi, 1,'last');
    la_min_idx = find(geoid.la < pt_la, 1,'last');
    la_max_idx = find(geoid.la > pt_la, 1,'first');
    
    % nastavi koordinate vogalov celice
    fi_1 = geoid.fi(fi_min_idx);
    fi_2 = geoid.fi(fi_max_idx);
    la_1 = geoid.la(la_min_idx);
    la_2 = geoid.la(la_max_idx);

    % nastavi geoidne višine vogalov celice
    N11 = geoid.N(fi_min_idx, la_min_idx);
    N21 = geoid.N(fi_min_idx, la_max_idx);
    N22 = geoid.N(fi_max_idx, la_max_idx);
    N12 = geoid.N(fi_max_idx, la_min_idx);
    

    LS = struct('fi', fi_1, 'la', la_1, 'N', N11);    % vogal levo spodaj
    DS = struct('fi', fi_1, 'la', la_2, 'N', N21);    % vogal desno spodaj
    DZ = struct('fi', fi_2, 'la', la_2, 'N', N22);    % vogal desno zgoraj
    LZ = struct('fi', fi_2, 'la', la_1, 'N', N12);    % vogal levo zgoraj


    %          la_1                        la_2
    %            |                           |
    % fi_2    --N12-------------------------N22-- fi_2
    %            |                           |
    %            |                           |
    %            |                           |
    %            |                           |
    %            |                           |
    %            |                           |
    %            |                           |
    %            |                           |
    %            |                           |
    %            |                           |
    %            |                           |
    % fi_1    --N11-------------------------N21-- fi_1
    %            |                           |
    %          la_1                        la_2

end